@@ -23,6 +23,7 @@ m4_define([b4_value_type_setup_variant])
 # Check the value of %define parse.lac, where LAC stands for lookahead
 # correction.
 b4_percent_define_default([[parse.lac]], [[none]])
+b4_percent_define_check_values([[[[parse.lac]], [[full]], [[none]]]])
 b4_define_flag_if([lac])
 m4_define([b4_lac_flag],
           [m4_if(b4_percent_define_get([[parse.lac]]),
@@ -1339,7 +1340,7 @@ b4_error_verbose_if([state_type yystate, const symbol_type& yyla],
         yyarg[yycount++] = yytname_[yytoken];]b4_lac_if([[
 
 #if ]b4_api_PREFIX[DEBUG
-        // Execute LAC once. We don't care if it is succesful, we
+        // Execute LAC once. We don't care if it is successful, we
         // only do it for the sake of debugging output.
         if (!yy_lac_established_)
           yy_lac_check_ (yytoken);
